@@ -1,6 +1,6 @@
 // Wrapper of C-language FILE struct -*- C++ -*-
 
-// Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2009
+// Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2009, 2010
 // Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
@@ -27,9 +27,9 @@
 // ISO C++ 14882: 27.8  File-based streams
 //
 
-/** @file basic_file.h
+/** @file bits/basic_file.h
  *  This is an internal header file, included by other library headers.
- *  You should not attempt to use it directly.
+ *  Do not attempt to use it directly. @headername{ios}
  */
 
 #ifndef _GLIBCXX_BASIC_FILE_STDIO_H
@@ -41,7 +41,9 @@
 #include <bits/c++io.h>  // for __c_lock and __c_file
 #include <ios>
 
-_GLIBCXX_BEGIN_NAMESPACE(std)
+namespace std _GLIBCXX_VISIBILITY(default)
+{
+_GLIBCXX_BEGIN_NAMESPACE_VERSION
 
   // Generic declaration.
   template<typename _CharT>
@@ -103,6 +105,7 @@ _GLIBCXX_BEGIN_NAMESPACE(std)
       showmanyc();
     };
 
-_GLIBCXX_END_NAMESPACE
+_GLIBCXX_END_NAMESPACE_VERSION
+} // namespace
 
 #endif	
